
import os

from .utils import read_yaml, set_environment_config, set_logging


class SetEnvironment:
    """
    A class to set up the environment configuration for the project.

    This class reads environment and credentials configuration from YAML files,
    sets up the environment based on the specified environment name, and
    optionally configures logging.

    Attributes:
        credentials (dict): Credentials loaded from the credentials YAML file.
        environment_config (dict): Environment configuration for the specified environment.
        logger (logging.Logger): Logger object if config_logger is True.

    Args:
        root_dir (str): Root directory of the project.
        environment_name (str): Name of the environment to set up. Defaults to "DEV".
        environment_path (str): Path to the environment YAML file, relative to root_dir. Defaults to "conf/local/environment.yml".
        credentials_path (str): Path to the credentials YAML file, relative to root_dir. Defaults to "conf/local/credentials.yml".
        config_logger (bool): Whether to configure logging. Defaults to True.
    """

    def __init__(
        self,
        root_dir,
        environment_name="DEV",
        environment_path="conf/local/environment.yml",
        credentials_path="conf/local/credentials.yml",
        config_logger=True,
    ) -> None:
        self.root_dir = root_dir
        self.credentials = read_yaml(os.path.join(root_dir, credentials_path))
        self.environment_config = set_environment_config(
            os.path.join(root_dir, environment_path), environment_name
        )

        for key, value in self.environment_config.items():
            setattr(self, key, value)

        if config_logger:
            self.logger = set_logging(self.PROJECT_NAME)
        elif config_logger is False:
            self.logger = None
        else:
            raise ValueError("config_logger must be a boolean value")


import os
from datetime import datetime
import logging
import yaml
import logging.config

def read_yaml(file_path):
    with open(file_path, "r") as file:
        return yaml.safe_load(file)
    
def set_environment_config(file_path, environment_name):
    config = read_yaml(file_path)
    gen_config = config.get("GENERAL", {})
    env_config = config.get(environment_name, {})
    if env_config:
        gen_config.update(env_config)
    else:
        print("error")

    return gen_config

def set_logging(project_name, log_path="logs", versioned_logger = True, log_console = True):
   
    if not os.path.exists(log_path):
        os.mkdir(log_path)

    with open("conf/base/logging.yml", "r") as file:
        config = yaml.safe_load(file)

    if versioned_logger:
        logger_filename = os.path.join(
            log_path,
            f"{datetime.now().strftime('%Y%m%d_%H%M%S')}_{project_name}.log",
        )
        config["handlers"]["info_file_handler"]["filename"] = logger_filename

    if not log_console:
        config["root"]["handlers"] = ["info_file_handler"]

    logging.config.dictConfig(config)

    logger = logging.getLogger(__name__)

    logger.info("Development Environment Setup successful")
    logger.info("Development Environment Variables Setup succesfully")
    return logger
    